expand_trials: Expand trials

expand_trialsR Documentation

Expand trials

Description

[Experimental]

Usage

expand_trials(object)

Arguments

object

A trial_sequence object

Value

The trial_sequence object with a data set containing the full sequence of target trials. The data is stored according to the options set with set_expansion_options() and especially the ⁠save_to_*⁠ function.


TrialEmulation documentation built on Aug. 25, 2026, 5:08 p.m.