trial_sequence-class: Trial Sequence class

trial_sequence-classR Documentation

Trial Sequence class

Description

Trial Sequence class

Slots

data

te_data.

estimand

character. Descriptive name of estimand.

expansion

te_expansion

outcome_model

te_outcome_model.

outcome_data

te_outcome_data.

censor_weight

te_weight. Object to define weighting to account for informative censoring

censor_weight

te_weight. Object to define weighting to account for informative censoring due to treatment switching


TrialEmulation documentation built on Aug. 25, 2026, 5:08 p.m.