| trial_sequence-class | R Documentation |
Trial Sequence class
datate_data.
estimandcharacter. Descriptive name of estimand.
expansionte_expansion
outcome_modelte_outcome_model.
outcome_datate_outcome_data.
censor_weightte_weight. Object to define weighting to account for informative censoring
censor_weightte_weight. Object to define weighting to account for informative censoring due to treatment switching
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.